<?php
/**
 * @file
 * Contains \Drupal\tmgmt_xtm\Plugin\QueueWorker\JobQueue.
 */
namespace Drupal\tmgmt_xtm\Plugin\QueueWorker;

use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\tmgmt\Entity\Job;
use Drupal\tmgmt_xtm\Controller\RemoteCallbackController;
use Drupal\tmgmt_xtm\Plugin\tmgmt\Translator\Connector;
use Symfony\Component\HttpFoundation\Response;

/**
 *
 * @QueueWorker(
 *   id = "callback_job_queue",
 *   title = @Translation("Callback Job queue"),
 *   cron = {"time" = 3600}
 * )
 */
class JobQueue extends QueueWorkerBase {
  /**
   * {@inheritdoc}
   */
  public function processItem($data)
  {
    foreach ($data['tmgmtJobIds'] as $jobId) {
      /** @var Job $job */
      $job = \Drupal::entityTypeManager()->getStorage(RemoteCallbackController::TMGMT_JOB)->load($jobId);

      if ($this->isInvalidProjectInJob($job, $data)) {
        \Drupal::logger('job')->error('Invalid project in job '. $jobId);
      }
      $connector = new Connector();
      if (isset($data['xtmJobId'])) {
        $connector->setXtmJobId($data['xtmJobId']);
      }
      $connector->retrieveTranslation($job);
    }
  }

  /**
   * @param $job
   * @param array $data
   * @return bool
   */
  private function isInvalidProjectInJob($job, $data)
  {
    $jobArray = $job->reference->getValue();
    return !$job || (int)$jobArray[0]['value'] != $data['xtmProjectId'];
  }
}
